@@ -9,6 +9,7 @@ extern "C" {
     fn mBufferToBigIntSigned(mBufferHandle: i32, bigIntHandle: i32) -> i32;
     fn mBufferFromBigIntUnsigned(mBufferHandle: i32, bigIntHandle: i32) -> i32;
     fn mBufferFromBigIntSigned(mBufferHandle: i32, bigIntHandle: i32) -> i32;
+    fn validateTokenIdentifier(token_id_handle: i32) -> i32;
 }
 
 impl elrond_wasm::api::ManagedTypeApi for crate::VmApiImpl {
@@ -51,4 +52,9 @@ impl elrond_wasm::api::ManagedTypeApi for crate::VmApiImpl {
             buffer_handle
         }
     }
+
+    #[cfg(feature = "vm-validate-token-identifier")]
+    fn validate_token_identifier(&self, token_id_handle: Handle) -> bool {
+        unsafe { validateTokenIdentifier(token_id_handle) != 0 }
+    }
 }
